@@ -63,6 +63,7 @@ plot(rock.gam, se=TRUE, pages=0)
 rock.gam1 <- gam(log(perm) ~ area + peri + s(shape), data=rock)
 par(mfrow=c(1,1))
 plot(rock.gam1, se=TRUE)
+par(pty="m")
 #anova(rock.lm, rock.gam1, rock.gam)
 #detach()
 
@@ -107,7 +108,9 @@ birthwt.gam <- gam(low ~ s(age) + s(lwt) + smoke + ptd +
     ht + ui + ftv + s(age1) + s(age2) + smoke:ui, binomial, bwt)
 birthwt.gam
 table(low, predict(birthwt.gam, bwt) > 0)
-if(interactive())plot(birthwt.gam, se=T)
+par(mfrow=c(2,2))
+plot(birthwt.gam, se=T)
+par(mfrow=c(1,1))
 detach()
 
 
